#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#  @Time    : 2020/2/28 16:15
#  @Author  : Evan.hu
#  @File    : operation_json

import jsonpath

class OperetionJson(object):
    def __init__(self, text):
        self.text = text

    # 根据传入字段获取json的值
    def get_value(self, name):
        # 当不存在name这个key时，返回false
        data = jsonpath.jsonpath(self.text, '$..{name}'.format(name=name))
        return data


from aishu import setting
from aishu.datafaker.profession.entity import date


def sql(key):
    """
    对应数据服务的sql语句注册
    :param key:
    :return:
    """
    switcher = {
        'SavedSearchID': {'sql':"select id from Kibana where type = 'search';",'database':'AnyRobot'},
        'SavedSearchNameID': {'sql':"select title from Kibana where id = '{id}';".format(id="" if not date.saved_search_Id_List else date.saved_search_Id_List[0]),'database':'AnyRobot'},
        'serviceID': {'sql':"select id from KAIService;",'database':'AnyRobot'},
        'KpiID': {'sql':"select id from KAIKpi where serviceId = '{id}';".format(id="" if not date.Service_Id_List else date.Service_Id_List[0]),'database':'AnyRobot'},
        'SavedSearchLogGroupID': {'sql':"select json_extract(json_extract(json_extract(searchSourceJSON,'$.filter[0]'),'$.meta'),'$.index') from Kibana where id = '{id}';".format(id="" if not date.saved_search_Id_List else date.saved_search_Id_List[0]),'database':'AnyRobot'},
        'SavedSearchLogLibraryID': {'sql':"select json_extract(json_extract(json_extract(searchSourceJSON,'$.filter[0]'),'$.meta'),'$.value') from Kibana where id = '{id}';".format(id="" if not date.saved_search_Id_List else date.saved_search_Id_List[0]),'database':'AnyRobot'},
        'AlertRuleNamesID': {'sql':"select alert_rule_name from RuleEngineAlert;",'database':'AnyRobot'},
        'AlertScenarioID': {'sql':"select id from RuleEngineAlertScenario;",'database':'AnyRobot'},
        'DeleteAlertRuleNamesID': {'sql':"select alert_rule_names from RuleEngineAlertScenario where id = '{id}';".format(id="" if not date.AlertScenario_Id_List else date.AlertScenario_Id_List[0]),'database':'AnyRobot'}
    }

    if switcher.get(key) is not None:
        if switcher[key].get('database') is not None:
            if len(switcher[key]['database']) == 0:
                setting.database = 'AnyRobot'
            else:
                setting.database = switcher[key]['database']

        return switcher[key]['sql']
    else:
        return False



from aishu.datafaker.anyrobot.getSqlVaule import AnyRobotDataServer
from aishu.datafaker.profession.getFiledValue import filed
from aishu import setting

class faker():
    def __init__(self,host,port,user,password,database):
        self.host = host
        self.port = port
        self.user = user
        self.password = password
        self.database = database
        setting.host = self.host
        setting.port = self.port
        setting.user = self.user
        setting.password = self.password
        setting.database = self.database

    def route(self,key,result=[]):
        date = AnyRobotDataServer(key).getValue()
        if isinstance(date, bool):
            date = filed(key, result)
            return date
        else:
            return date

if __name__ == '__main__':
    host = '192.168.84.26'
    key1 = 's_id'
    port = 30006
    user = 'root'
    password = 'eisoo.com'
    database = 'AnyRobot'
    date1 = faker(host,port,user,password,database).route(key1)
    print(date1)


import uuid
from aishu.public.db_select import select

class date(object):
    def getUUid(self):
        uuidStr = uuid.uuid4()
        return str(uuidStr)

    def getAsLogWareID(self):
        sql='select id from LogWareHouse where dataType="as访问日志"'
        sqldata = select(sql)
        if len(sqldata) != 1:
            return False

        return sqldata[0][0]

    def getDefaultLogGroupID(self):
        sql = 'select groupId from `LogGroup` where groupName="所有日志"'
        sqldata = select(sql)
        if isinstance(sqldata,bool):
            return False

        if  len(sqldata) !=1:
            return False

        return sqldata[0][0]


    def getAdminID(self):
        sql = 'select userId from `User` where loginName="admin"'
        sqldata = select(sql)
        if not (sqldata):
            return False

        return sqldata[0][0]



import random
from aishu.datafaker.anyrobot.sqlMapping import sql
from aishu.public.db_select import select

class AnyRobotDataServer(object):
    def __init__(self,key):
        self.key = key
        self.sql = sql(self.key)

    def getValue(self):
        ar_id_list = []
        if isinstance(self.sql,bool):
            return False

        date = select(self.sql)
        if isinstance(date,bool):
            return False

        if len(date) == 0:
            return False

        for value in date:
            ar_id_list.append(value[0])
        return random.choice(ar_id_list)


import requests
from aishu import setting

class machine(object):
    def __init__(self, search):
        self.search = search

    def getAgentPort(self):
        if not (self.search):
            return False

        ip = setting.host
        headers = setting.header
        ports = []
        url = 'http://{ip}/etl/input/list?start=0&limit=-1&order=create_time&by=desc'.format(ip=ip)
        rsp = requests.get(url=url,headers=headers)
        inputList=rsp.json()

        for key in self.search:
            for input in inputList:
                if input['id'] == key:
                    ports.append(input['port'])
                    break

        if not (ports):
            return False

        if len(ports)==1:
            return str(ports[0])
        else:
            return ports
    def getIntPort(self):
        if not (self.search):
            return False

        ip = setting.host
        headers = setting.header
        ports = []
        url = 'http://{ip}/etl/input/list?start=0&limit=-1&order=create_time&by=desc'.format(ip=ip)
        rsp = requests.get(url=url,headers=headers)
        inputList=rsp.json()

        for key in self.search:
            for input in inputList:
                if input['id'] == key:
                    ports.append(input['port'])
                    break

        if not (ports):
            return False

        if len(ports)==1:
            return ports[0]
        else:
            return ports



host = ''
port = ''
user = ''
password = ''
database = 'AnyRobot'

header = {
    'Accept': 'application/json, text/plain, */*',
    'Accept-Encoding': 'gzip, deflate',
    'Accept-Language': 'zh-CN,zh;q=0.9',
    'Connection': 'keep-alive',
    'Content-Type': 'application/json;charset=UTF-8'
}


import jsonpath
import requests,json
from aishu import setting
from aishu.datafaker.profession.entity import id

class search(object):
    def createSearchId(self):
        url = "http://{ip}/v1/search/submit".format(ip=setting.host)
        logGroup = id.date().getDefaultLogGroupID()
        payload = [
            {
                "logGroup": logGroup,
                "query": "*",
                "sort": [
                    {
                        "@timestamp": "desc"
                    }
                ],
                "size": 10,
                "needFieldList": True,
                "filters": {
                    "must": [
                        {
                            "@timestamp": {
                                "from": 1441001644796,
                                "to": 1598854444796
                            }
                        }
                    ],
                    "must_not": []
                }
            }
        ]
        headers = setting.header

        rsp = requests.request("POST", url, headers=headers, data = json.dumps(payload))
        s_id = jsonpath.jsonpath(rsp.json(), '$..{name}'.format(name='id'))
        if isinstance(s_id,bool):
            return False
        else:
            return s_id[0]

if __name__ == '__main__':
    setting.host = "192.168.84.35"
    setting.database = 'AnyRobot'
    setting.password = 'eisoo.com'
    setting.port = 30006
    setting.user = 'root'
    date = search().createSearchId()
    print(date)


import traceback
from aishu.public.mysql_pool import connection

def select(sql):
    try:
        conn = connection()
        cursor = conn.cursor()
        cursor.execute(sql)
        data = cursor.fetchall()
        cursor.close()
        conn.close()
        return data
    except Exception as e:
        traceback.print_exc()
        return False


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time    : 2021/01/26 16:03
# @Author  : xiong.yuanzhou
import random,json
from aishu.datafaker.profession.entity import date
from aishu.datafaker.profession.entity.AssociationMapping import sql
from aishu.public.db_select import select

class ParaDateAnyRobotServer(object):
    def __init__(self,key):
        self.key = key
        self.sql = sql(self.key)

    def getSavedSearchId(self):
        ar_id_list = []
        if isinstance(self.sql, bool):
            return 0
        Id_date = select(self.sql)
        if len(Id_date) == 0:
            return 0
        for value in Id_date:
            ar_id_list.append(value[0])
        SavedSearch_Id = random.choice(ar_id_list)
        date.saved_search_Id_List.append(SavedSearch_Id)
        return date.saved_search_Id_List[0]


    def getSavedSearchNameId(self):
        # 查询id对应的Name
        if isinstance(self.sql, bool):
            return 0
        Name_date = select(self.sql)
        if len(Name_date) == 0:
            return 0
        return Name_date[0][0]


    def getSavedSearchLogGroupId(self):
        # 查询id对应的SavedSearchLogGroupId
        if isinstance(self.sql, bool):
            return 0
        date = select(self.sql)
        if len(date) == 0:
            return 0
        return date[0][0].replace("\"", "")


    def getSavedSearchLogLibraryId(self):
        # 查询对应的SavedSearchLogLibraryId
        if isinstance(self.sql, bool):
            return 0
        date = select(self.sql)
        if len(date) == 0:
            return 0
        return date[0][0].replace("\"", "")


    def getAlertRuleNamesId(self):
        ar_id_list = []
        date = select(self.sql)
        if len(date) == 0:
            return 0
        for value in date:
            ar_id_list.append(value[0])
        return random.choice(ar_id_list)


    def getAlertScenarioId(self):
        ar_id_list = []
        if isinstance(self.sql, bool):
            return 0
        Id_date = select(self.sql)
        if len(Id_date) == 0:
            return 0
        for value in Id_date:
            ar_id_list.append(value[0])
        SavedSearch_Id = random.choice(ar_id_list)
        date.AlertScenario_Id_List.append(SavedSearch_Id)
        return date.AlertScenario_Id_List[0]


    def getDeleteAlertRuleNamesId(self):
        # 查询场景策略id对应的规则策略名称
        if isinstance(self.sql, bool):
            return 0
        Name_date = select(self.sql)
        if len(Name_date) == 0:
            return 0
        filter = json.loads(Name_date[0][0])[0]
        return filter


    def getServiceId(self):
        ar_id_list = []
        if isinstance(self.sql, bool):
            return 0
        Id_date = select(self.sql)
        if len(Id_date) == 0:
            return 0
        for value in Id_date:
            ar_id_list.append(value[0])
        date.Service_Id_List.append(random.choice(ar_id_list))
        return date.Service_Id_List[0]


    def getKpiId(self):
        # 查询服务对应的KPIId
        if isinstance(self.sql, bool):
            return 0
        Name_date = select(self.sql)
        if len(Name_date) == 0:
            return 0
        return Name_date[0][0]



from aishu import setting

def sql(key):
    """
    对应数据服务的sql语句注册
    :param key:
    :return:
    """
    switcher = {
        'UserID':{'sql':'select userId from User where loginName = "admin";','database':'AnyRobot'},
        'MLID': {'sql': "select id from MLJob ;", 'database': 'AnyRobotML'},
        'entityID': {'sql': "select id from KAIEntity;", 'database': 'AnyRobot'},
        'groupID': {'sql': "select id from KAIEntityGroup;", 'database': 'AnyRobot'},
        'AlertRuleID': {'sql': "select id from RuleEngineAlert;", 'database': 'AnyRobot'},
        'kpiID': {'sql': "select id from KAIKpi;", 'database': 'AnyRobot'},
        'LogTypeID': {'sql': "select dataType from LogWareHouse;", 'database': 'AnyRobot'},
        'AddEntityID': {
            'sql': "select entityId from KAIEntityCondition where conditionValues = '192.168.84.26' AND conditionKeys = 'host';",
            'database': 'AnyRobot'},
        'KpiTemplateID': {'sql': "select id from KAIKpiTemplate;", 'database': 'AnyRobot'},
        'KpiTemplateID1': {'sql': "select id from KAIKpiTemplate;", 'database': 'AnyRobot'},
        'KpiTemplateID2': {'sql': "select id from KAIKpiTemplate;", 'database': 'AnyRobot'},
        'LogwareHouse': {'sql': "SELECT id From LogWareHouse where LENGTH(id)!=8;", 'database': 'AnyRobot'},
        'logWareHouseId': {'sql': "SELECT id From LogWareHouse where LENGTH(id)!=8;", 'database': 'AnyRobot'},
        'dataType': {'sql': "SELECT dataType From LogWareHouse where LENGTH(id)!=8;", 'database': 'AnyRobot'},
        'indexID': {'sql': "SELECT id From IndexParams;", 'database': 'AnyRobot'},
        'indexName': {'sql': "SELECT indexName From IndexParams;", 'database': 'AnyRobot'},
        'StreamId': {'sql': "SELECT name From DataStream;", 'database': 'AnyRobot'},
        'LogGroupIdPare': {'sql': 'SELECT groupId From LogGroup where GroupName="所有日志";', 'database': 'AnyRobot'},
        'RoleId': {'sql': 'SELECT roleId From Role where roleName ="admin";', 'database': 'AnyRobot'},
        'tagGroupID': {'sql': "SELECT id From TagGroup;", 'database': 'AnyRobot'},
        'tagID': {'sql': "SELECT id From Tag;", 'database': 'AnyRobot'},
        'HostID': {'sql': "SELECT ip From AgentHost;", 'database': 'AnyRobot'},
        'openapiID': {'sql': "SELECT id From OpenAPIManager;", 'database': 'AnyRobotOpenLog'},
        'UserID_Notadmin': {'sql': 'select userId from User where loginName != "admin";', 'database': 'AnyRobot'}
    }

    if switcher.get(key) is not None:
        if switcher[key].get('database') is not None:
            if len(switcher[key]['database']) == 0:
                setting.database = 'AnyRobot'
            else:
                setting.database = switcher[key]['database']

        return switcher[key]['sql']
    else:
        return False



from aishu import setting
from aishu.datafaker.profession.entity import name, switch, ip, timestamp, ml, kai, objectManager, index, agent ,id ,port
from aishu.datafaker.profession.entity import zx
from aishu.datafaker.profession.entity.ParaDateFiled import ParaDateFiledServer
from aishu.datafaker.profession.entity.RetrievesAssociated import ParaDateAnyRobotServer

def filed(key,inquire=[]):
    """
    :param key:
    :return:
    """
    SERVICE_KPI_ = {
        'AnyRobotNameID': name.date().getName,
        'AnyRobotOtherNameID': name.date().getName,
        'Closed': switch.date().getSwClosed,
        'Open': switch.date().getSwOpen,
        'UUid': id.date().getUUid,
        'IpVR': ip.date().getIpVR,
        'IPError': ip.date().getIpError,
        'startTime': timestamp.date().getStartTime,
        'endTime': timestamp.date().getEndTime,
        'lastHourTime': timestamp.date().getLastHourTime,
        'lastTime':timestamp.date().getLastTime,
        'getEtlPortOld': port.date().getEtlPortOld,
        'getEtlPortNew': port.date().getEtlPortNew,
        'getEtlPortIll': port.date().getEtlPortIll,
        'enity': ml.machine(inquire).inquire,
        'entityHost': kai.machine(inquire).inquireEntity,
        'serviceKpiId': kai.machine(inquire).inquireServiceKpi,
        'businessKpiIdAndServiceId':kai.machine(inquire).inquireBusinessKPIAndServiceId,
        'ServiceBusinessID':kai.machine(inquire).ServiceBusiness,
        'pensInfo':kai.machine(inquire).inquirePens,
        'testHostIP':ip.date().getTestHostIP,
        'rarserRuleName': objectManager.date().getRuleNameId,
        'dashboardId': objectManager.date().getDashboardId,
        'searchId': objectManager.date().getSearchId,
        'visualizationId': objectManager.date().getVisualizationId,
        'indexId':index.date().getIndexId,
        'indexList':index.date().getIndexName,
        'indexList_as':index.date().getIndexTypeAs,
        'DateTime':timestamp.date().getDateTime,
        'agentPort': agent.machine(inquire).getAgentPort,
        'AlertAgentPort': agent.machine(inquire).getIntPort,
        'intPort':agent.machine(inquire).getIntPort,
        'adminID':id.date().getAdminID,
        'DefaultLogGroupID':id.date().getDefaultLogGroupID,
        'asLogWareID':id.date().getAsLogWareID,
        'httpUrl':kai.machine(inquire).getAlertHttpUrl,
        'lastFiveYearTime':timestamp.date().getLastFiveYearTime,
        'alertmergeID': ParaDateFiledServer().getUUid,
        'fromID': ParaDateFiledServer().getFromTime,
        'ToID': ParaDateFiledServer().getToTime,
        'StartDateID': ParaDateFiledServer().getStartDate,
        'EndDateID': ParaDateFiledServer().getEndDate,
        'TimeRangeID': ParaDateFiledServer().getTimeRangeId,
        'RangeUnitID': ParaDateFiledServer().getRangeUnitId,
        'TimeLabelID': ParaDateFiledServer().getTimeLabelId,
        'serviceID': ParaDateAnyRobotServer(key).getServiceId,
        'KpiID': ParaDateAnyRobotServer(key).getKpiId,
        'kpiNameID': ParaDateFiledServer().getkpiNameID,
        'kpiNameId': ParaDateFiledServer().kpiNameId,
        'SavedSearchID': ParaDateAnyRobotServer(key).getSavedSearchId,
        'SavedSearchNameID': ParaDateAnyRobotServer(key).getSavedSearchNameId,
        'SavedSearchLogGroupID': ParaDateAnyRobotServer(key).getSavedSearchLogGroupId,
        'SavedSearchLogLibraryID': ParaDateAnyRobotServer(key).getSavedSearchLogLibraryId,
        'AlertRuleNamesID': ParaDateAnyRobotServer(key).getAlertRuleNamesId,
        'AlertScenarioID': ParaDateAnyRobotServer(key).getAlertScenarioId,
        'DeleteAlertRuleNamesID': ParaDateAnyRobotServer(key).getDeleteAlertRuleNamesId,
        'UpdateTimeID': ParaDateFiledServer().getUpdateTime,
        'UtcStartID': ParaDateFiledServer().getUtcStartTime,
        'UtcEndID': ParaDateFiledServer().getUtcEndTime,
        's_id': zx.search().createSearchId
    }

    switcher = SERVICE_KPI_
    if switcher.get(key) is not None:
        return switcher[key]()
    else:
        return False

if __name__ == '__main__':
    setting.host = ""
    setting.database = 'AnyRobot'
    setting.password = ''
    setting.port = 30006
    setting.user = ''
    date = filed("UpdateTimeID")
    print(date)


import requests
from aishu.public.db_select import select
from aishu import setting

class machine(object):
    def __init__(self, search):
        self.search = search

    def inquireServiceKpi(self):
        serviceKpi = []

        if not (self.search):
            return False

        for key in self.search:
            sql = 'SELECT serviceId,id From KAIKpi where KAIKpi.serviceId={serverID}'.format(serverID=key)
            date = select(sql)
            for sqlDate in date:
                serviceKpi.append(list(sqlDate))
        #当没有查询找数据时，返回错误
        if not (serviceKpi):
            return False

        context = [
            {"key": serviceKpi[0], "operator": "matches", "value": ["2", "0", "3", "4", "5", "6"], "type": "kpi"},
            {"key": serviceKpi[1], "operator": "matches", "value": ["0", "2", "3", "4", "5", "6"], "type": "kpi"},
            {"key": serviceKpi[2], "operator": "matches", "value": ["2", "0", "3", "4", "5", "6"], "type": "kpi"}
        ]
        return context

    def inquireEntity(self):
        entityhostIps = []

        if not (self.search):
            return False

        for key in self.search:
            sql = 'SELECT fieldsCondition From KAIEntity where id={EntityId}'.format(EntityId=key)
            sqldata = select(sql)
            for key in sqldata:
                for entityRules in key:
                    entityRules = eval(entityRules)
                    for entityRule  in entityRules:
                        entityhostIps.append(entityRule['value'])
        #当没有查询找数据时，返回错误
        if not (entityhostIps):
            return False
        data = [{"fieldsCondition": [{"host": {"matches": entityhostIps}}]}]
        return data

    def inquireBusinessKPIAndServiceId(self):
        id=[]
        if not (self.search):
            return False

        for key in self.search:
            sql = 'SELECT serviceId,id From KAIKpi where KAIKpi.serviceId={serverID}'.format(serverID=key)
            sqldata = select(sql)
            for i in sqldata:
                id.append(list(i))
        if not (id):
            return False
        data = [{"id":id[0][1],"type":"kpi"},{"id":id[0][0],"type":"service"}]
        return data

    def ServiceBusiness(self):
        nameAndId=[]
        if not (self.search):
            return False

        for key in self.search:
            sql='SELECT KAIKpi.`name`,KAIKpi.id,KAIService.`name`,KAIKpi.serviceId FROM KAIService INNER JOIN KAIKpi ON KAIService.id = KAIKpi.serviceId WHERE KAIService.id = {serverID}'.format(serverID=key)
            sqldata = select(sql)
            for info in sqldata:

                nameAndId=list(info)
        if not (nameAndId):
            return False

        data = [
            {
                "type": 0,
                "rect": {
                    "x": 442,
                    "y": 265.5,
                    "width": 70,
                    "height": 100,
                    "center": {
                        "x": 477,
                        "y": 315.5
                    },
                    "ex": 512,
                    "ey": 365.5
                },
                "lineWidth": 1,
                "rotate": 0,
                "offsetRotate": 0,
                "globalAlpha": 1,
                "dash": 0,
                "strokeStyle": "#000000",
                "font": {
                    "color": "#000000",
                    "fontFamily": "\"Hiragino Sans GB\", \"Microsoft YaHei\", \"Helvetica Neue\", Helvetica, Arial",
                    "fontSize": 12,
                    "lineHeight": 1.5,
                    "fontStyle": "normal",
                    "fontWeight": "normal",
                    "textAlign": "center",
                    "textBaseline": "middle",
                    "background": ""
                },
                "animateCycleIndex": 0,
                "events": [],
                "eventFns": [
                    "link",
                    "doAnimate",
                    "doFn",
                    "doWindowFn"
                ],
                "id": "ab82928",
                "name": "people",
                "tags": [],
                "lineDashOffset": 0,
                "textOffsetX": 0,
                "textOffsetY": 0,
                "animateType": "",
                "visible": True,
                "data": "",
                "zRotate": 0,
                "anchors": [
                    {
                        "x": 442,
                        "y": 315.5,
                        "direction": 4
                    },
                    {
                        "x": 477,
                        "y": 265.5,
                        "direction": 1
                    },
                    {
                        "x": 512,
                        "y": 315.5,
                        "direction": 2
                    },
                    {
                        "x": 477,
                        "y": 365.5,
                        "direction": 3
                    }
                ],
                "rotatedAnchors": [
                    {
                        "x": 442,
                        "y": 315.5,
                        "direction": 4
                    },
                    {
                        "x": 477,
                        "y": 265.5,
                        "direction": 1
                    },
                    {
                        "x": 512,
                        "y": 315.5,
                        "direction": 2
                    },
                    {
                        "x": 477,
                        "y": 365.5,
                        "direction": 3
                    }
                ],
                "animateDuration": 0,
                "animateFrames": [],
                "z": None,
                "borderRadius": 0,
                "iconSize": 0,
                "imageAlign": "center",
                "gradientAngle": 0,
                "gradientRadius": 0.01,
                "paddingTop": 0,
                "paddingBottom": 0,
                "paddingLeft": 0,
                "paddingRight": 0,
                "paddingLeftNum": 0,
                "paddingRightNum": 0,
                "paddingTopNum": 0,
                "paddingBottomNum": 0,
                "textRect": {
                    "x": 0,
                    "y": 0,
                    "width": 0,
                    "height": 0,
                    "center": {
                        "x": 0,
                        "y": 0
                    },
                    "ex": 0,
                    "ey": 0
                },
                "fullTextRect": {
                    "x": 0,
                    "y": 0,
                    "width": 0,
                    "height": 0,
                    "center": {
                        "x": 0,
                        "y": 0
                    },
                    "ex": 0,
                    "ey": 0
                },
                "iconRect": {
                    "x": 0,
                    "y": 0,
                    "width": 0,
                    "height": 0,
                    "center": {
                        "x": 0,
                        "y": 0
                    },
                    "ex": 0,
                    "ey": 0
                },
                "elementRendered": False,
                "TID": "ec085cd",
                "lastImage": None,
                "dockWatchers": [
                    {
                        "x": 477,
                        "y": 315.5
                    },
                    {
                        "x": 0,
                        "y": 276.5
                    },
                    {
                        "x": 70,
                        "y": 276.5
                    },
                    {
                        "x": 70,
                        "y": 376.5
                    },
                    {
                        "x": 0,
                        "y": 376.5
                    }
                ]
            },
            {
                "type": 0,
                "rect": {
                    "x": 622,
                    "y": 210,
                    "width": 200,
                    "height": 80,
                    "center": {
                        "x": 722,
                        "y": 250
                    },
                    "ex": 822,
                    "ey": 290
                },
                "lineWidth": 1,
                "rotate": 0,
                "offsetRotate": 0,
                "globalAlpha": 1,
                "dash": 0,
                "strokeStyle": "transparent",
                "fillStyle": "#ffffff",
                "font": {
                    "color": "#000000",
                    "fontFamily": "\"Hiragino Sans GB\", \"Microsoft YaHei\", \"Helvetica Neue\", Helvetica, Arial",
                    "fontSize": 12,
                    "lineHeight": 1.5,
                    "fontStyle": "normal",
                    "fontWeight": "normal",
                    "textAlign": "center",
                    "textBaseline": "middle"
                },
                "animateCycleIndex": 0,
                "events": [],
                "eventFns": [
                    "link",
                    "doAnimate",
                    "doFn",
                    "doWindowFn"
                ],
                "id": "531cfaa9",
                "name": "echarts",
                "tags": [],
                "lineDashOffset": 0,
                "textOffsetX": 0,
                "textOffsetY": 0,
                "animateType": "",
                "hideInput": True,
                "visible": True,
                "data": {
                    "text": "{serviceName}_服务健康分数".format(serviceName=nameAndId[2]),
                    "echarts": {
                        "option": {
                            "title": {
                                "text": "服务健康分数",
                                "subtext": "",
                                "left": "center",
                                "top": "bottom",
                                "textStyle": {
                                    "fontFamily": "Microsoft YaHei",
                                    "fontSize": 12,
                                    "fontWeight": "normal",
                                    "color": "#000000",
                                    "lineHeight": 12,
                                    "rich": {
                                        "e": {
                                            "color": "red"
                                        }
                                    }
                                },
                                "subtextStyle": {
                                    "fontSize": 12,
                                    "color": "red"
                                }
                            },
                            "tooltip": {
                                "trigger": "axis",
                                "padding": [
                                    8,
                                    12
                                ]
                            },
                            "grid": [
                                {
                                    "left": 2,
                                    "right": "32.3%",
                                    "borderColor": "transparent",
                                    "top": 2,
                                    "bottom": 24,
                                    "backgroundColor": "#ffe1a8",
                                    "show": True
                                },
                                {
                                    "left": 2,
                                    "right": "33%",
                                    "bottom": 24,
                                    "backgroundColor": "transparent",
                                    "borderColor": "transparent",
                                    "show": True
                                },
                                {
                                    "x": "68%",
                                    "right": 2,
                                    "left": "68%",
                                    "top": 2,
                                    "bottom": 24,
                                    "backgroundColor": "#ffe1a8",
                                    "borderColor": "transparent",
                                    "show": True
                                }
                            ],
                            "xAxis": [
                                {
                                    "gridIndex": 0,
                                    "type": "category",
                                    "data": [
                                        1610935980000,
                                        1610936100000,
                                        1610936220000
                                    ],
                                    "show": False
                                },
                                {
                                    "show": False
                                }
                            ],
                            "yAxis": [
                                {
                                    "gridIndex": 0,
                                    "type": "value",
                                    "show": False
                                },
                                {
                                    "show": False
                                }
                            ],
                            "series": [
                                {
                                    "animation": False,
                                    "hoverAnimation": False,
                                    "data": [
                                        70,
                                        70,
                                        70
                                    ],
                                    "smooth": True,
                                    "showSymbol": True,
                                    "yAxisIndex": 0,
                                    "symbol": "none",
                                    "xAxisIndex": 0,
                                    "symbolSize": 0,
                                    "type": "line",
                                    "lineStyle": {
                                        "color": "#000000"
                                    },
                                    "itemStyle": {
                                        "color": "#000000"
                                    }
                                },
                                {
                                    "tooltip": {
                                        "trigger": "item",
                                        "formatter": "70",
                                        "padding": [
                                            8,
                                            12
                                        ],
                                        "position": [
                                            "80%",
                                            "-50%"
                                        ]
                                    },
                                    "color": "#000000",
                                    "animation": False,
                                    "avoidLabelOverlap": True,
                                    "hoverAnimation": False,
                                    "data": [
                                        {
                                            "value": 100,
                                            "name": "--"
                                        }
                                    ],
                                    "name": "",
                                    "radius": [
                                        "46%",
                                        "46%"
                                    ],
                                    "label": {
                                        "show": True,
                                        "position": "center",
                                        "fontSize": 20,
                                        "formatter": "70",
                                        "rich": {
                                            "n": {
                                                "fontSize": 12
                                            }
                                        }
                                    },
                                    "center": [
                                        "83%",
                                        "44%"
                                    ],
                                    "type": "pie"
                                }
                            ],
                            "severity": [
                                3,
                                3,
                                3
                            ],
                            "type": "service"
                        },
                        "rect": {
                            "width": 200,
                            "height": 80
                        }
                    },
                    "data": {
                        "dataName": "{serviceName}_服务健康分数".format(serviceName=nameAndId[2]),
                        "id": nameAndId[3],
                        "isNotFound": False,
                        "parentId": "{serviceId}".format(serviceId=nameAndId[3]),
                        "type": "service"
                    }
                },
                "zRotate": 0,
                "anchors": [
                    {
                        "x": 622,
                        "y": 250,
                        "direction": 4
                    },
                    {
                        "x": 722,
                        "y": 210,
                        "direction": 1
                    },
                    {
                        "x": 822,
                        "y": 250,
                        "direction": 2
                    },
                    {
                        "x": 722,
                        "y": 290,
                        "direction": 3
                    }
                ],
                "rotatedAnchors": [
                    {
                        "x": 622,
                        "y": 250,
                        "direction": 4
                    },
                    {
                        "x": 722,
                        "y": 210,
                        "direction": 1
                    },
                    {
                        "x": 822,
                        "y": 250,
                        "direction": 2
                    },
                    {
                        "x": 722,
                        "y": 290,
                        "direction": 3
                    }
                ],
                "animateDuration": 0,
                "animateFrames": [],
                "borderRadius": 0,
                "iconSize": None,
                "imageAlign": "center",
                "gradientAngle": 0,
                "gradientRadius": 0.01,
                "paddingTop": 0,
                "paddingBottom": 0,
                "paddingLeft": 0,
                "paddingRight": 0,
                "elementId": "e406b09",
                "paddingLeftNum": 0,
                "paddingRightNum": 0,
                "paddingTopNum": 0,
                "paddingBottomNum": 0,
                "textRect": {
                    "x": 622,
                    "y": 270,
                    "width": 200,
                    "height": 20,
                    "center": {
                        "x": 722,
                        "y": 280
                    },
                    "ex": 822,
                    "ey": 290
                },
                "fullTextRect": {
                    "x": 622,
                    "y": 210,
                    "width": 200,
                    "height": 80,
                    "center": {
                        "x": 722,
                        "y": 250
                    },
                    "ex": 822,
                    "ey": 290
                },
                "iconRect": {
                    "x": 622,
                    "y": 210,
                    "width": 200,
                    "height": 60,
                    "center": {
                        "x": 722,
                        "y": 240
                    },
                    "ex": 822,
                    "ey": 270
                },
                "fullIconRect": {
                    "x": 622,
                    "y": 210,
                    "width": 200,
                    "height": 80,
                    "center": {
                        "x": 722,
                        "y": 250
                    },
                    "ex": 822,
                    "ey": 290
                },
                "elementRendered": True,
                "TID": "ec085cd",
                "elementLoaded": True,
                "dockWatchers": [
                    {
                        "x": 722,
                        "y": 250
                    },
                    {
                        "x": 622,
                        "y": 210
                    },
                    {
                        "x": 822,
                        "y": 210
                    },
                    {
                        "x": 822,
                        "y": 290
                    },
                    {
                        "x": 622,
                        "y": 290
                    }
                ]
            },
            {
                "type": 0,
                "rect": {
                    "x": 622,
                    "y": 336.5,
                    "width": 200,
                    "height": 80,
                    "center": {
                        "x": 722,
                        "y": 376.5
                    },
                    "ex": 822,
                    "ey": 416.5
                },
                "lineWidth": 1,
                "rotate": 0,
                "offsetRotate": 0,
                "globalAlpha": 1,
                "dash": 0,
                "strokeStyle": "transparent",
                "fillStyle": "#ffffff",
                "font": {
                    "color": "#000000",
                    "fontFamily": "\"Hiragino Sans GB\", \"Microsoft YaHei\", \"Helvetica Neue\", Helvetica, Arial",
                    "fontSize": 12,
                    "lineHeight": 1.5,
                    "fontStyle": "normal",
                    "fontWeight": "normal",
                    "textAlign": "center",
                    "textBaseline": "middle"
                },
                "animateCycleIndex": 0,
                "events": [],
                "eventFns": [
                    "link",
                    "doAnimate",
                    "doFn",
                    "doWindowFn"
                ],
                "id": "83348a3",
                "name": "echarts",
                "tags": [],
                "lineDashOffset": 0,
                "textOffsetX": 0,
                "textOffsetY": 0,
                "animateType": "",
                "hideInput": True,
                "visible": True,
                "data": {
                    "text": "{serviceName}_{KPIName}".format(serviceName=nameAndId[2],KPIName=nameAndId[0]),
                    "echarts": {
                        "option": {
                            "title": {
                                "text": "{KPIName}".format(KPIName=nameAndId[0]),
                                "subtext": "",
                                "left": "center",
                                "top": "bottom",
                                "textStyle": {
                                    "fontFamily": "Microsoft YaHei",
                                    "fontSize": 12,
                                    "fontWeight": "normal",
                                    "color": "#000000",
                                    "lineHeight": 12,
                                    "rich": {
                                        "e": {
                                            "color": "red"
                                        }
                                    }
                                },
                                "subtextStyle": {
                                    "fontSize": 12,
                                    "color": "red"
                                }
                            },
                            "tooltip": {
                                "trigger": "axis",
                                "padding": [
                                    8,
                                    12
                                ]
                            },
                            "grid": [
                                {
                                    "left": 2,
                                    "right": "32.3%",
                                    "borderColor": "transparent",
                                    "top": 2,
                                    "bottom": 24,
                                    "backgroundColor": "#ffe1a8",
                                    "show": True
                                },
                                {
                                    "left": 2,
                                    "right": "33%",
                                    "bottom": 24,
                                    "backgroundColor": "transparent",
                                    "borderColor": "transparent",
                                    "show": True
                                },
                                {
                                    "x": "68%",
                                    "right": 2,
                                    "left": "68%",
                                    "top": 2,
                                    "bottom": 24,
                                    "backgroundColor": "#ffe1a8",
                                    "borderColor": "transparent",
                                    "show": True
                                }
                            ],
                            "xAxis": [
                                {
                                    "gridIndex": 0,
                                    "type": "category",
                                    "data": [
                                        1610935980000,
                                        1610936100000,
                                        1610936220000
                                    ],
                                    "show": False
                                },
                                {
                                    "show": False
                                }
                            ],
                            "yAxis": [
                                {
                                    "gridIndex": 0,
                                    "type": "value",
                                    "show": False
                                },
                                {
                                    "show": False
                                }
                            ],
                            "series": [
                                {
                                    "animation": False,
                                    "hoverAnimation": False,
                                    "data": [
                                        345,
                                        355,
                                        383
                                    ],
                                    "smooth": True,
                                    "showSymbol": True,
                                    "yAxisIndex": 0,
                                    "symbol": "none",
                                    "xAxisIndex": 0,
                                    "symbolSize": 0,
                                    "type": "line",
                                    "lineStyle": {
                                        "color": "#000000"
                                    },
                                    "itemStyle": {
                                        "color": "#000000"
                                    }
                                },
                                {
                                    "tooltip": {
                                        "trigger": "item",
                                        "formatter": "383条",
                                        "padding": [
                                            8,
                                            12
                                        ],
                                        "position": [
                                            "80%",
                                            "-50%"
                                        ]
                                    },
                                    "color": "#000000",
                                    "animation": False,
                                    "avoidLabelOverlap": True,
                                    "hoverAnimation": False,
                                    "data": [
                                        {
                                            "value": 100,
                                            "name": "--"
                                        }
                                    ],
                                    "name": "",
                                    "radius": [
                                        "46%",
                                        "46%"
                                    ],
                                    "label": {
                                        "show": True,
                                        "position": "center",
                                        "fontSize": 20,
                                        "formatter": "38...",
                                        "rich": {
                                            "n": {
                                                "fontSize": 12
                                            }
                                        }
                                    },
                                    "center": [
                                        "83%",
                                        "44%"
                                    ],
                                    "type": "pie"
                                }
                            ],
                            "severity": [
                                3,
                                3,
                                3
                            ],
                            "type": "kpi"
                        },
                        "rect": {
                            "width": 200,
                            "height": 80
                        }
                    },
                    "data": {
                        "dataName": "{serviceName}_{KPIName}".format(serviceName=nameAndId[2],KPIName=nameAndId[0]),
                        "id": nameAndId[1],
                        "isNotFound": False,
                        "parentId": "{serviceId}".format(serviceId=nameAndId[3]),
                        "type": "kpi"
                    }
                },
                "zRotate": 0,
                "anchors": [
                    {
                        "x": 622,
                        "y": 376.5,
                        "direction": 4
                    },
                    {
                        "x": 722,
                        "y": 336.5,
                        "direction": 1
                    },
                    {
                        "x": 822,
                        "y": 376.5,
                        "direction": 2
                    },
                    {
                        "x": 722,
                        "y": 416.5,
                        "direction": 3
                    }
                ],
                "rotatedAnchors": [
                    {
                        "x": 622,
                        "y": 376.5,
                        "direction": 4
                    },
                    {
                        "x": 722,
                        "y": 336.5,
                        "direction": 1
                    },
                    {
                        "x": 822,
                        "y": 376.5,
                        "direction": 2
                    },
                    {
                        "x": 722,
                        "y": 416.5,
                        "direction": 3
                    }
                ],
                "animateDuration": 0,
                "animateFrames": [],
                "borderRadius": 0,
                "iconSize": None,
                "imageAlign": "center",
                "gradientAngle": 0,
                "gradientRadius": 0.01,
                "paddingTop": 0,
                "paddingBottom": 0,
                "paddingLeft": 0,
                "paddingRight": 0,
                "elementId": "58cbaa",
                "paddingLeftNum": 0,
                "paddingRightNum": 0,
                "paddingTopNum": 0,
                "paddingBottomNum": 0,
                "textRect": {
                    "x": 622,
                    "y": 396.5,
                    "width": 200,
                    "height": 20,
                    "center": {
                        "x": 722,
                        "y": 406.5
                    },
                    "ex": 822,
                    "ey": 416.5
                },
                "fullTextRect": {
                    "x": 622,
                    "y": 336.5,
                    "width": 200,
                    "height": 80,
                    "center": {
                        "x": 722,
                        "y": 376.5
                    },
                    "ex": 822,
                    "ey": 416.5
                },
                "iconRect": {
                    "x": 622,
                    "y": 336.5,
                    "width": 200,
                    "height": 60,
                    "center": {
                        "x": 722,
                        "y": 366.5
                    },
                    "ex": 822,
                    "ey": 396.5
                },
                "fullIconRect": {
                    "x": 622,
                    "y": 336.5,
                    "width": 200,
                    "height": 80,
                    "center": {
                        "x": 722,
                        "y": 376.5
                    },
                    "ex": 822,
                    "ey": 416.5
                },
                "elementRendered": True,
                "TID": "ec085cd",
                "elementLoaded": True,
                "dockWatchers": [
                    {
                        "x": 722,
                        "y": 376.5
                    },
                    {
                        "x": 622,
                        "y": 336.5
                    },
                    {
                        "x": 822,
                        "y": 336.5
                    },
                    {
                        "x": 822,
                        "y": 416.5
                    },
                    {
                        "x": 622,
                        "y": 416.5
                    }
                ]
            },
            {
                "type": 1,
                "rect": {
                    "x": 0,
                    "y": 0,
                    "width": 0,
                    "height": 0,
                    "center": {
                        "x": 0,
                        "y": 0
                    },
                    "ex": 0,
                    "ey": 0
                },
                "lineWidth": 1,
                "rotate": 0,
                "offsetRotate": 0,
                "globalAlpha": 1,
                "dash": 0,
                "strokeStyle": "#000000",
                "fillStyle": "",
                "font": {
                    "color": "",
                    "fontFamily": "\"Hiragino Sans GB\", \"Microsoft YaHei\", \"Helvetica Neue\", Helvetica, Arial",
                    "fontSize": 12,
                    "lineHeight": 1.5,
                    "fontStyle": "normal",
                    "fontWeight": "normal",
                    "textAlign": "center",
                    "textBaseline": "middle",
                    "background": "#fff"
                },
                "animateCycleIndex": 0,
                "events": [],
                "eventFns": [
                    "link",
                    "doAnimate",
                    "doFn",
                    "doWindowFn"
                ],
                "id": "d561b63",
                "name": "curve",
                "tags": [],
                "lineDashOffset": 0,
                "textOffsetX": 0,
                "textOffsetY": 0,
                "visible": True,
                "data": "",
                "controlPoints": [
                    {
                        "x": 592,
                        "y": 315.5,
                        "direction": 2,
                        "anchorIndex": 2,
                        "id": "ab82928"
                    },
                    {
                        "x": 542,
                        "y": 250,
                        "direction": 4,
                        "anchorIndex": 0,
                        "id": "531cfaa9"
                    }
                ],
                "fromArrowSize": 5,
                "toArrowSize": 5,
                "borderWidth": 0,
                "borderColor": "#000000",
                "animateColor": "",
                "animateSpan": 1,
                "animatePos": 0,
                "isAnimate": False,
                "animateFromSize": 0,
                "animateToSize": 0,
                "animateDotSize": 3,
                "from": {
                    "x": 512,
                    "y": 315.5,
                    "direction": 2,
                    "anchorIndex": 2,
                    "id": "ab82928"
                },
                "to": {
                    "x": 622,
                    "y": 250,
                    "direction": 4,
                    "anchorIndex": 0,
                    "id": "531cfaa9"
                },
                "fromArrow": "",
                "toArrow": "triangleSolid",
                "textRect": None,
                "TID": "ec085cd"
            },
            {
                "type": 1,
                "rect": {
                    "x": 0,
                    "y": 0,
                    "width": 0,
                    "height": 0,
                    "center": {
                        "x": 0,
                        "y": 0
                    },
                    "ex": 0,
                    "ey": 0
                },
                "lineWidth": 1,
                "rotate": 0,
                "offsetRotate": 0,
                "globalAlpha": 1,
                "dash": 0,
                "strokeStyle": "#000000",
                "fillStyle": "",
                "font": {
                    "color": "",
                    "fontFamily": "\"Hiragino Sans GB\", \"Microsoft YaHei\", \"Helvetica Neue\", Helvetica, Arial",
                    "fontSize": 12,
                    "lineHeight": 1.5,
                    "fontStyle": "normal",
                    "fontWeight": "normal",
                    "textAlign": "center",
                    "textBaseline": "middle",
                    "background": "#fff"
                },
                "animateCycleIndex": 0,
                "events": [],
                "eventFns": [
                    "link",
                    "doAnimate",
                    "doFn",
                    "doWindowFn"
                ],
                "id": "730113e",
                "name": "curve",
                "tags": [],
                "lineDashOffset": 0,
                "textOffsetX": 0,
                "textOffsetY": 0,
                "visible": True,
                "data": "",
                "controlPoints": [
                    {
                        "x": 592,
                        "y": 315.5,
                        "direction": 2,
                        "anchorIndex": 2,
                        "id": "ab82928"
                    },
                    {
                        "x": 542,
                        "y": 376.5,
                        "direction": 4,
                        "anchorIndex": 0,
                        "id": "83348a3"
                    }
                ],
                "fromArrowSize": 5,
                "toArrowSize": 5,
                "borderWidth": 0,
                "borderColor": "#000000",
                "animateColor": "",
                "animateSpan": 1,
                "animatePos": 0,
                "isAnimate": False,
                "animateFromSize": 0,
                "animateToSize": 0,
                "animateDotSize": 3,
                "from": {
                    "x": 512,
                    "y": 315.5,
                    "direction": 2,
                    "anchorIndex": 2,
                    "id": "ab82928"
                },
                "to": {
                    "x": 622,
                    "y": 376.5,
                    "direction": 4,
                    "anchorIndex": 0,
                    "id": "83348a3"
                },
                "fromArrow": "",
                "toArrow": "triangleSolid",
                "textRect": None,
                "TID": "ec085cd"
            }
        ]

        return data

    def inquirePens(self):
        nameAndId=[]
        if not (self.search):
            return False

        for key in self.search:
            sql='SELECT KAIKpi.`name`,KAIKpi.id,KAIService.`name`,KAIKpi.serviceId FROM KAIService INNER JOIN KAIKpi ON KAIService.id = KAIKpi.serviceId WHERE KAIService.id = {serverID}'.format(serverID=key)
            sqldata = select(sql)
            for info in sqldata:

                nameAndId=list(info)
        if not (nameAndId):
            return False

        data=[
            {"type":0, "rect":{"x":546,"y":268,"width":582,"height":117,"center":{"x":837,"y":326.5},"ex":1128,"ey":385}, "lineWidth":1, "rotate":0, "offsetRotate":0,"globalAlpha":1,"dash":0,"strokeStyle":"transparent","fillStyle":"#ffffff", "font":{"color":"#000000","fontFamily":"\"Hiragino Sans GB\", \"Microsoft YaHei\", \"Helvetica Neue\", Helvetica, Arial","fontSize":12,"lineHeight":1.5,"fontStyle":"normal","fontWeight":"normal","textAlign":"center","textBaseline":"middle"}, "animateCycleIndex":0,"events":[],"eventFns":["link","doAnimate","doFn","doWindowFn"],"id":"d0c90c4","name":"echarts","tags":[],"lineDashOffset":0,"textOffsetX":0,"textOffsetY":0,"animateType":"","hideInput":True,"visible":True,
            "data":{"text":"{serviceName}_{KPIName}".format(serviceName=nameAndId[2],KPIName=nameAndId[0]),"echarts":{"option":{"title":{"text":"KPI251_606","subtext":"","left":"center","top":"bottom","textStyle":{"fontFamily":"Microsoft YaHei","fontSize":12,"fontWeight":"normal","color":"#000000","lineHeight":12,"rich":{"e":{"color":"red"}}},"subtextStyle":{"fontSize":12,"color":"red"}},"tooltip":{"trigger":"axis","padding":[8,12]},"grid":[{"left":2,"right":"32.3%","borderColor":"transparent","top":2,"bottom":24,"backgroundColor":"rgba(0, 0, 0, 0.15)","show":True},{"left":2,"right":"33%","bottom":24,"backgroundColor":"transparent","borderColor":"transparent","show":True},{"x":"68%","right":2,"left":"68%","top":2,"bottom":24,"backgroundColor":"rgba(0, 0, 0, 0.15)","borderColor":"transparent","show":True}],"xAxis":[{"gridIndex":0,"type":"category","data":[],"show":False},{"show":False}],"yAxis":[{"gridIndex":0,"type":"value","show":False},{"show":False}],"series":[{"animation":False,"hoverAnimation":False,"data":[],"smooth":True,"showSymbol":True,"yAxisIndex":0,"symbol":"none","xAxisIndex":0,"symbolSize":0,"type":"line","lineStyle":{"color":"#000000"},"itemStyle":{"color":"#000000"}},{"tooltip":{"trigger":"item","formatter":"N/A条","padding":[8,12],"position":["80%","-50%"]},"color":"#000000","animation":False,"avoidLabelOverlap":True,"hoverAnimation":False,"data":[{"value":100,"name":"--"}],"name":"","radius":["46%","46%"],"label":{"show":True,"position":"center","fontSize":20,"formatter":"N/A条","rich":{"n":{"fontSize":12}}},"center":["83%","44%"],"type":"pie"}],"severity":[],"type":"kpi"},"rect":{"width":200,"height":80}},"data":{"dataName":"{serviceName}_{KPIName}".format(serviceName=nameAndId[2],KPIName=nameAndId[0]),"id":nameAndId[1],"isNotFound":False,"parentId":"{serviceId}".format(serviceId=nameAndId[3]),"type":"kpi"}},"zRotate":0,"anchors":[{"x":546,"y":326.5,"direction":4},{"x":837,"y":268,"direction":1},{"x":1128,"y":326.5,"direction":2},{"x":837,"y":385,"direction":3}],"rotatedAnchors":[{"x":546,"y":326.5,"direction":4},{"x":837,"y":268,"direction":1},{"x":1128,"y":326.5,"direction":2},{"x":837,"y":385,"direction":3}],"animateDuration":0,"animateFrames":[],"borderRadius":0,"iconSize":None,"imageAlign":"center","gradientAngle":0,"gradientRadius":0.01,"paddingTop":0,"paddingBottom":0,"paddingLeft":0,"paddingRight":0,"elementId":"8c5cca5","paddingLeftNum":0,"paddingRightNum":0,"paddingTopNum":0,"paddingBottomNum":0,"textRect":{"x":546,"y":355.75,"width":582,"height":29.25,"center":{"x":837,"y":370.375},"ex":1128,"ey":385},"fullTextRect":{"x":546,"y":268,"width":582,"height":117,"center":{"x":837,"y":326.5},"ex":1128,"ey":385},"iconRect":{"x":546,"y":268,"width":582,"height":87.75,"center":{"x":837,"y":311.875},"ex":1128,"ey":355.75},"fullIconRect":{"x":546,"y":268,"width":582,"height":117,"center":{"x":837,"y":326.5},"ex":1128,"ey":385},"elementRendered":True,"TID":"c576c97","elementLoaded":True,"dockWatchers":[{"x":837,"y":326.5},{"x":306,"y":274},{"x":888,"y":274},{"x":888,"y":391},{"x":306,"y":391}]},
            {"type":0,"rect":{"x":161,"y":286.5,"width":200,"height":80,"center":{"x":261,"y":326.5},"ex":361,"ey":366.5},"lineWidth":1,"rotate":0,"offsetRotate":0,"globalAlpha":1,"dash":0,"strokeStyle":"transparent","fillStyle":"#ffffff","font":{"color":"#000000","fontFamily":"\"Hiragino Sans GB\", \"Microsoft YaHei\", \"Helvetica Neue\", Helvetica, Arial","fontSize":12,"lineHeight":1.5,"fontStyle":"normal","fontWeight":"normal","textAlign":"center","textBaseline":"middle"},"animateCycleIndex":0,"events":[],"eventFns":["link","doAnimate","doFn","doWindowFn"],"id":"f1f3b2c","name":"echarts","tags":[],"lineDashOffset":0,"textOffsetX":0,"textOffsetY":0,"animateType":"","hideInput":True,"visible":True,
            "data":{"text":"{serviceName}_服务健康分数".format(serviceName=nameAndId[2]), "echarts":{"option":{"title":{"text":"服务健康分数","subtext":"","left":"center","top":"bottom","textStyle":{"fontFamily":"Microsoft YaHei","fontSize":12,"fontWeight":"normal","color":"#000000","lineHeight":12,"rich":{"e":{"color":"red"}}},"subtextStyle":{"fontSize":12,"color":"red"}},"tooltip":{"trigger":"axis","padding":[8,12]},"grid":[{"left":2,"right":"32.3%","borderColor":"transparent","top":2,"bottom":24,"backgroundColor":"rgba(0, 0, 0, 0.15)","show":True},{"left":2,"right":"33%","bottom":24,"backgroundColor":"transparent","borderColor":"transparent","show":True},{"x":"68%","right":2,"left":"68%","top":2,"bottom":24,"backgroundColor":"rgba(0, 0, 0, 0.15)","borderColor":"transparent","show":True}],"xAxis":[{"gridIndex":0,"type":"category","data":[],"show":False},{"show":False}],"yAxis":[{"gridIndex":0,"type":"value","show":False},{"show":False}],"series":[{"animation":False,"hoverAnimation":False,"data":[],"smooth":True,"showSymbol":True,"yAxisIndex":0,"symbol":"none","xAxisIndex":0,"symbolSize":0,"type":"line","lineStyle":{"color":"#000000"},"itemStyle":{"color":"#000000"}},{"tooltip":{"trigger":"item","formatter":"N/A","padding":[8,12],"position":["80%","-50%"]},"color":"#000000","animation":False,"avoidLabelOverlap":True,"hoverAnimation":False,"data":[{"value":100,"name":"--"}],"name":"","radius":["46%","46%"],"label":{"show":True,"position":"center","fontSize":20,"formatter":"N/A","rich":{"n":{"fontSize":12}}},"center":["83%","44%"],"type":"pie"}],"severity":[],"type":"service"},"rect":{"width":200,"height":80}},"data":{"dataName":"{serviceName}_服务健康分数".format(serviceName=nameAndId[2]),"id":nameAndId[3],"isNotFound":False,"parentId":"{serviceId}".format(serviceId=nameAndId[3]),"type":"service"}},"zRotate":0,"anchors":[{"x":161,"y":326.5,"direction":4},{"x":261,"y":286.5,"direction":1},{"x":361,"y":326.5,"direction":2},{"x":261,"y":366.5,"direction":3}],"rotatedAnchors":[{"x":161,"y":326.5,"direction":4},{"x":261,"y":286.5,"direction":1},{"x":361,"y":326.5,"direction":2},{"x":261,"y":366.5,"direction":3}],"animateDuration":0,"animateFrames":[],"borderRadius":0,"iconSize":None,"imageAlign":"center","gradientAngle":0,"gradientRadius":0.01,"paddingTop":0,"paddingBottom":0,"paddingLeft":0,"paddingRight":0,"elementId":"aa0e60f","paddingLeftNum":0,"paddingRightNum":0,"paddingTopNum":0,"paddingBottomNum":0,"textRect":{"x":161,"y":346.5,"width":200,"height":20,"center":{"x":261,"y":356.5},"ex":361,"ey":366.5},"fullTextRect":{"x":161,"y":286.5,"width":200,"height":80,"center":{"x":261,"y":326.5},"ex":361,"ey":366.5},"iconRect":{"x":161,"y":286.5,"width":200,"height":60,"center":{"x":261,"y":316.5},"ex":361,"ey":346.5},"fullIconRect":{"x":161,"y":286.5,"width":200,"height":80,"center":{"x":261,"y":326.5},"ex":361,"ey":366.5},"elementRendered":True,"TID":"c576c97","elementLoaded":True,"dockWatchers":[{"x":261,"y":326.5},{"x":-17,"y":292.5},{"x":183,"y":292.5},{"x":183,"y":372.5},{"x":-17,"y":372.5}]},
            {"type":1,"rect":{"x":0,"y":0,"width":0,"height":0,"center":{"x":0,"y":0},"ex":0,"ey":0},"lineWidth":1,"rotate":0,"offsetRotate":0,"globalAlpha":1,"dash":0,"strokeStyle":"#000000","fillStyle":"","font":{"color":"","fontFamily":"\"Hiragino Sans GB\", \"Microsoft YaHei\", \"Helvetica Neue\", Helvetica, Arial","fontSize":12,"lineHeight":1.5,"fontStyle":"normal","fontWeight":"normal","textAlign":"center","textBaseline":"middle","background":"#fff"},"animateCycleIndex":0,"events":[],"eventFns":["link","doAnimate","doFn","doWindowFn"],"id":"335f03","name":"curve","tags":[],"lineDashOffset":0,"textOffsetX":0,"textOffsetY":0,"visible":True,"data":"","controlPoints":[{"x":422,"y":326.5,"direction":2,"anchorIndex":2,"id":"f1f3b2c"},{"x":485,"y":326.5,"direction":4,"anchorIndex":0,"id":"d0c90c4"}],"fromArrowSize":5,"toArrowSize":5,"borderWidth":0,"borderColor":"#000000","animateColor":"","animateSpan":1,"animatePos":0,"isAnimate":False,"animateFromSize":0,"animateToSize":0,"animateDotSize":3,"from":{"x":361,"y":326.5,"direction":2,"anchorIndex":2,"id":"f1f3b2c"},"to":{"x":546,"y":326.5,"direction":4,"anchorIndex":0,"id":"d0c90c4"},"fromArrow":"","toArrow":"straightLine","textRect":None,"TID":"c576c97"},
            {"type":0,"rect":{"x":0,"y":276.5,"width":70,"height":100,"center":{"x":35,"y":326.5},"ex":70,"ey":376.5},"lineWidth":1,"rotate":0,"offsetRotate":0,"globalAlpha":1,"dash":0,"strokeStyle":"#000000","font":{"color":"#000000","fontFamily":"\"Hiragino Sans GB\", \"Microsoft YaHei\", \"Helvetica Neue\", Helvetica, Arial","fontSize":12,"lineHeight":1.5,"fontStyle":"normal","fontWeight":"normal","textAlign":"center","textBaseline":"middle"},"animateCycleIndex":0,"events":[],"eventFns":["link","doAnimate","doFn","doWindowFn"],"id":"ab82928","name":"people","tags":[],"lineDashOffset":0,"textOffsetX":0,"textOffsetY":0,"animateType":"","visible":True,"data":"","zRotate":0,"anchors":[{"x":0,"y":326.5,"direction":4},{"x":35,"y":276.5,"direction":1},{"x":70,"y":326.5,"direction":2},{"x":35,"y":376.5,"direction":3}],"rotatedAnchors":[{"x":0,"y":326.5,"direction":4},{"x":35,"y":276.5,"direction":1},{"x":70,"y":326.5,"direction":2},{"x":35,"y":376.5,"direction":3}],"animateDuration":0,"animateFrames":[],"borderRadius":0,"iconSize":None,"imageAlign":"center","gradientAngle":0,"gradientRadius":0.01,"paddingTop":0,"paddingBottom":0,"paddingLeft":0,"paddingRight":0,"paddingLeftNum":0,"paddingRightNum":0,"paddingTopNum":0,"paddingBottomNum":0,"textRect":{"x":0,"y":0,"width":0,"height":0,"center":{"x":0,"y":0},"ex":0,"ey":0},"fullTextRect":{"x":0,"y":0,"width":0,"height":0,"center":{"x":0,"y":0},"ex":0,"ey":0},"iconRect":{"x":0,"y":0,"width":0,"height":0,"center":{"x":0,"y":0},"ex":0,"ey":0},"elementRendered":False,"TID":"c576c97"},
            {"type":1,"rect":{"x":0,"y":0,"width":0,"height":0,"center":{"x":0,"y":0},"ex":0,"ey":0},"lineWidth":1,"rotate":0,"offsetRotate":0,"globalAlpha":1,"dash":0,"strokeStyle":"#000000","fillStyle":"","font":{"color":"","fontFamily":"\"Hiragino Sans GB\", \"Microsoft YaHei\", \"Helvetica Neue\", Helvetica, Arial","fontSize":12,"lineHeight":1.5,"fontStyle":"normal","fontWeight":"normal","textAlign":"center","textBaseline":"middle","background":"#fff"},"animateCycleIndex":0,"events":[],"eventFns":["link","doAnimate","doFn","doWindowFn"],"id":"19931a69","name":"curve","tags":[],"lineDashOffset":0,"textOffsetX":0,"textOffsetY":0,"visible":True,"data":"","controlPoints":[{"x":100,"y":326.5,"direction":2,"anchorIndex":2,"id":"ab82928"},{"x":131,"y":326.5,"direction":4,"anchorIndex":0,"id":"f1f3b2c"}],"fromArrowSize":5,"toArrowSize":5,"borderWidth":0,"borderColor":"#000000","animateColor":"","animateSpan":1,"animatePos":0,"isAnimate":False,"animateFromSize":0,"animateToSize":0,"animateDotSize":3,"from":{"x":70,"y":326.5,"direction":2,"anchorIndex":2,"id":"ab82928"},"to":{"x":161,"y":326.5,"direction":4,"anchorIndex":0,"id":"f1f3b2c"},"fromArrow":"","toArrow":"straightLine","textRect":None,"TID":"c576c97"}
        ]

        return data


    def getAlertHttpUrl(self):
        if not (self.search):
            return False

        ip = setting.host
        headers = setting.header
        ports = []
        url = 'http://{ip}/etl/input/list?start=0&limit=-1&order=create_time&by=desc'.format(ip=ip)
        rsp = requests.get(url=url,headers=headers)
        inputList=rsp.json()

        for key in self.search:
            for input in inputList:
                if input['id'] == key:
                    ports.append(input['port'])
                    break

        if len(ports) != 1:
            return False

        return 'http://{ip}:{port}'.format(ip=ip,port=ports[0])


import time
import random

class date(object):
    def getStartTime(self):
        return int(round(time.time() * 1000))

    def getEndTime(self):
        return int(round(time.time() * 1000))

    def getLastHourTime(self):
        return int(round(time.time() * 1000)) - 3600000

    def getLastFiveYearTime(self):
        year = 365
        day = 24
        h = 60
        m = 60
        endTime = year * day * h * m * 1000 * 5
        return int(round(time.time() * 1000)) -endTime

    def getLastTime(self):
        year=365
        day=24
        h=60
        m=60
        endTime=year*day*h*m*1000
        startTime=300000
        return self.getStartTime()-random.randint(startTime,endTime)

    def getDateTime(self):
        return str(time.strftime('%Y-%m-%d %H:%M:%S'))



import random
from aishu.public.db_select import select

class date(object):

    def getIndexId(self):
        #查询数据库所有的索引表。
        sql = 'SELECT id from IndexParams;'
        sqldata = select(sql)
        indexIds=[]
        if not (sqldata):
            return False

        #将查询到的数据规范化，规范为一个list。
        for index  in sqldata:
            for indexId in index:
                indexIds.append(indexId)

        if not (indexIds):
            return False
        return indexIds[random.randint(0,len(indexIds)-1)]

    def getIndexName(self):
        sql = 'SELECT indexName from IndexParams;'
        sqldata = select(sql)
        indexNames=[]
        if not (sqldata):
            return False

        #将查询到的数据规范化，规范为一个list。
        for index  in sqldata:
            for indexName in index:
                indexNames.append(indexName)

        if not (indexNames):
            return False
        return indexNames[random.randint(0,len(indexNames)-1)]

    def getIndexTypeAs(self):
        indexNames = []

        #从数据库查找对应的索引名字
        sql = 'SELECT indexName from IndexParams where dataType="as";'
        sqldata = select(sql)

        if not (sqldata):
            return False

        #从返回元组中提取indexName
        for index  in sqldata:
            for indexName in index:
                indexNames.append(indexName)

        if not (indexNames):
            return False

        return indexNames



from DBUtils.PooledDB import PooledDB
import pymysql
from aishu import setting

def connection():
    POOL = PooledDB(
        creator=pymysql,  # 使用链接数据库的模块
        maxconnections=30,  # 连接池允许的最大连接数，0和None表示不限制连接数
        mincached=2,  # 初始化时，链接池中至少创建的空闲的链接，0表示不创建
        maxcached=5,  # 链接池中最多闲置的链接，0和None不限制
        maxshared=3,
        # 链接池中最多共享的链接数量，0和None表示全部共享。PS: 无用，因为pymysql和MySQLdb等模块的
        # threadsafety都为1，所有值无论设置为多少，_maxcached永远为0，所以永远是所有链接都共享。
        blocking=True,  # 连接池中如果没有可用连接后，是否阻塞等待。True，等待；False，不等待然后报错
        maxusage=None,  # 一个链接最多被重复使用的次数，None表示无限制
        setsession=[],  # 开始会话前执行的命令列表。如：["set datestyle to ...", "set time zone ..."]
        ping=0,
        # ping MySQL服务端，检查是否服务可用。# 如：0 = None = never, DbManagement = default = whenever
        # it is requested, 2 = when a cursor is created, 4 = when a query is
        # executed, 7 = always
        host=setting.host,
        port=setting.port,
        user=setting.user,
        password=setting.password,
        database=setting.database,
        charset='utf8'
    )
    conn = POOL.connection()
    return conn


import random

class date():
    def getName(self):
        name = str(random.choice(range(10, 999))) + '_' + str(random.choice(range(10, 999)))
        return name
    def getDataType(self):
        pass


import random
import requests
from aishu.public import urlJoin
from aishu.public.operationJson import OperetionJson
from aishu.setting import header


class date(object):
    def getPort(self):
        # 系统合法参数 20010-20099、162，514，5140
        portList = [port for port in range(20010, 20100)]
        portList.append(162)
        portList.append(514)
        portList.append(5140)
        port = random.choice(portList)
        return port

    def getEtlPort(self):
        path = "/etl/input/list?start=0&limit=-1"
        payload = {}
        headers = header
        response = requests.request("GET", urlJoin.url(path), headers=headers, data=payload)
        date = response.json()
        a = OperetionJson(date)
        value = a.get_value('port')
        if value:
            return value
        else:
            return []

    def getEtlPortOld(self):
        date = self.getEtlPort()
        if len(date) == 0:
            port = 0
            return port
        else:
            port = random.choice(date)
            return port

    def getEtlPortNew(self):
        oldNew = self.getEtlPort()
        count = 0
        flag = True
        while flag or count >= 10:
            newPort = self.getPort()
            count = count + 1
            if newPort not in oldNew:
                flag = False
                return newPort
        return ''

    def getEtlPortIll(self):
        portList = [port for port in range(10000, 20000)]
        port = random.choice(portList)
        return port




class machine(object):
    def __init__(self,search):
        self.search = search

    def inquire(self):
        if isinstance(self.search, list):
            return [12,23,45]
        else:
            return [34,56,67]


import urllib.request
from aishu.public.db_select import select

class date(object):
    # Kibana数据库保存对象管理所有的解析规则、仪表盘、搜索、可视化
    # 1.随机获取一个'解析规则'的ruleName
    def getRuleNameId(self):
        sql = 'SELECT ruleName From ParserRule  ORDER BY rand() LIMIT 1'
        rarserRuleName = urllib.parse.quote(select(sql)[0][0])
        return rarserRuleName


    # 2.随机获取一个'仪表盘'的id
    def getDashboardId(self):
        sql = 'SELECT id From Kibana  where Kibana.type = "dashboard" ORDER BY rand() LIMIT 1'
        dashboardId = select(sql)[0][0]
        return dashboardId

    # 3.随机获取一个'搜索'的id
    def getSearchId(self):
        sql = 'SELECT id From Kibana  where Kibana.type = "search" ORDER BY rand() LIMIT 1'
        searchId = select(sql)[0][0]
        return searchId

    # 4.随机获取一个'可视化'的id
    def getVisualizationId(self):
        sql = 'SELECT id From Kibana  where Kibana.type = "visualization" ORDER BY rand() LIMIT 1'
        visualizationId = select(sql)[0][0]
        return visualizationId


#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
from distutils.core import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__)) + os.path.sep + 'README.rst'

with open(here, "r") as f:
  long_description = f.read()

setup(name='AnyRobot',
      version='1.1.11',
      description='This is a data service module that solves test data problems.',
      long_description=long_description,
      author='Evan.hu',
      author_email='1056212287@qq.com',
      url='https://mp.weixin.qq.com/s/v6FS96ifCoMvp_rwrhzhKw',
      install_requires=[],
      license='BSD License',
      packages=find_packages(),
      platforms=["all"],
      classifiers=[
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
          'Natural Language :: Chinese (Simplified)',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Topic :: Software Development :: Libraries'
      ],
    )


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# @Time    : 2021/01/26 16:03
# @Author  : xiong.yuanzhou

import time
import random, uuid
import datetime
from aishu.datafaker.profession.entity import date

class ParaDateFiledServer(object):
    # def __init__(self,info):
    #     self.info = info
    """
    生成接口字段参数
    """

    def getName(self):
        name = str(random.choice(range(10, 999))) + '_' + str(random.choice(range(10, 999)))
        return name

    def getSwClosed(self):
        return 'disable'

    def getSwOpen(self):
        return 'enable'

    def getIp(self):
        ipList = ["192.168.84.105",
                  "192.168.84.192",
                  "192.168.84.217",
                  "192.168.84.108",
                  "192.168.84.107",
                  "192.168.84.182",
                  "192.168.84.193",
                  "192.168.84.109",
                  "192.168.84.175",
                  "192.168.84.60",
                  "192.168.84.61",
                  "192.168.84.63",
                  "192.168.84.62",
                  "192.168.84.64",
                  "192.168.84.65",
                  "192.168.84.66"]
        return random.choice(ipList)

    def getPort(self):
        # 系统合法参数 20010-20099、162，514，5140
        portList = [port for port in range(20010, 20100)]
        portList.append(162)
        portList.append(514)
        portList.append(5140)
        port = random.choice(portList)
        return port

    def getIpVR(self):
        return '{ip1}.{ip2}.{ip3}.{ip4}'.format(ip1=10, ip2=random.choice(range(10, 250)),
                                                ip3=random.choice(range(10, 250)), ip4=random.choice(range(10, 250)))

    def getIpError(self):
        return '{ip1}.{ip2}.{ip3}.{ip4}'.format(ip1='abc', ip2=random.choice(range(10, 99)),
                                                ip3=random.choice(range(10, 99)), ip4=random.choice(range(10, 99)))

    def getUUid(self):
        uuidStr = uuid.uuid4()
        return str(uuidStr)


    def getStartTime(self):
        return int(round(time.time() * 1000))

    def getEndTime(self):
        return int(round(time.time() * 1000))

    def getUpdateTime(self):
        return int(round(time.time()))

    def getEtlPortIll(self):
        portList = [port for port in range(10000, 20000)]
        port = random.choice(portList)
        return port

    def getFromTime(self):
        timeList = []
        differenceTime = 60 * 1000
        ToTime = self.getEndTime()
        timeList.append(ToTime - 30 * differenceTime)
        timeList.append(ToTime - 6 * 60 * differenceTime)
        timeList.append(ToTime - 12 * 60 * differenceTime)
        timeList.append(ToTime - 24 * 60 * differenceTime)
        startTime = random.choice(timeList)
        date.FromTime_List.append(startTime)
        date.ToTime_List.append(ToTime)
        return startTime

    def getToTime(self):
        return 0 if not date.ToTime_List else date.ToTime_List[0]

    def getUtcStartTime(self):
        year_1 = str(int(time.strftime("%Y", time.localtime())) - 1)
        year_2 = str(int(time.strftime("%Y", time.localtime())) - 2)
        year_3 = str(int(time.strftime("%Y", time.localtime())) - 3)
        year_4 = str(int(time.strftime("%Y", time.localtime())) - 4)
        year_5 = str(int(time.strftime("%Y", time.localtime())) - 5)
        time_list = [year_1, year_2, year_3, year_4, year_5]
        info = {
            'year': random.choice(time_list),
            'month': time.strftime("%m", time.localtime()),
            'day': time.strftime("%d", time.localtime()),
            'hour': time.strftime("%H", time.localtime()),
            'minute': time.strftime("%M", time.localtime()),
            'second': time.strftime("%S", time.localtime()),
        }
        ut_time = info['year'] + '-' + info['month'] + '-' + info['day'] + ' ' + info['hour'] + ':' + info['minute'] + ':' + info['second']
        bj_time = datetime.datetime.strptime(ut_time, "%Y-%m-%d %H:%M:%S") - datetime.timedelta(hours=8)
        bj_time_info = str(bj_time).split(' ')
        bj_time_year = str(bj_time_info[0]).split('-')
        bj_time_host = str(bj_time_info[1]).split(':')

        return bj_time_year[0] + '-' + bj_time_year[1] + '-' + bj_time_year[2] + 'T' + bj_time_host[0] + ':' + bj_time_host[1] + ':' + bj_time_host[2] + '.000Z'

    def getUtcEndTime(self):
        info = {
            'year': str(int(time.strftime("%Y", time.localtime())) + 1),
            'month': time.strftime("%m", time.localtime()),
            'day': time.strftime("%d", time.localtime()),
            'hour': time.strftime("%H", time.localtime()),
            'minute': time.strftime("%M", time.localtime()),
            'second': time.strftime("%S", time.localtime()),
        }
        ut_time = info['year'] + '-' + info['month'] + '-' + info['day'] + ' ' + info['hour'] + ':' + info['minute'] + ':' + info['second']
        bj_time = datetime.datetime.strptime(ut_time, "%Y-%m-%d %H:%M:%S") - datetime.timedelta(hours=8)
        bj_time_info = str(bj_time).split(' ')
        bj_time_year = str(bj_time_info[0]).split('-')
        bj_time_host = str(bj_time_info[1]).split(':')
        return bj_time_year[0] + '-' + bj_time_year[1] + '-' + bj_time_year[2] + 'T' + bj_time_host[0] + ':' + bj_time_host[1] + ':' + bj_time_host[2] + '.000Z'

    def getStartDate(self):
        startdate = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
        return startdate

    def getEndDate(self):
        enddate = (datetime.datetime.now() + datetime.timedelta(days=1)).strftime("%Y-%m-%d %H:%M:%S")
        return enddate

    def getkpiNameID(self):
        name = str(random.choice(range(10, 999))) + '_' + str(random.choice(range(10, 999)))
        return name

    def kpiNameId(self):
        name = str(random.choice(range(10, 999))) + '_' + str(random.choice(range(10, 999)))
        return name

    def getTimeRangeId(self):
        FromID = 0 if not date.FromTime_List else date.FromTime_List[0]
        ToID = 0 if not date.ToTime_List else date.ToTime_List[0]
        time_diff = ToID - FromID
        time_unit = {
            date.time_diff_value[0]: {
                'timeRange': 30,
                'rangeUnit': 'm',
                'timeLabel': 'last30Minutes'
            },
            date.time_diff_value[1]: {
                'timeRange': 6,
                'rangeUnit': 'h',
                'timeLabel': 'last6Hours'
            },
            date.time_diff_value[2]: {
                'timeRange': 12,
                'rangeUnit': 'h',
                'timeLabel': 'last12Hours'
            },
            date.time_diff_value[3]: {
                'timeRange': 24,
                'rangeUnit': 'h',
                'timeLabel': 'last24Hours'
            }
        }
        time_Info = time_unit[str(time_diff)]
        timeRange_Info = time_Info['timeRange']

        return timeRange_Info

    def getRangeUnitId(self):
        FromID = 0 if not date.FromTime_List else date.FromTime_List[0]
        ToID = 0 if not date.ToTime_List else date.ToTime_List[0]
        time_diff = ToID - FromID
        time_unit = {
            date.time_diff_value[0]: {
                'timeRange': 30,
                'rangeUnit': 'm',
                'timeLabel': 'last30Minutes'
            },
            date.time_diff_value[1]: {
                'timeRange': 6,
                'rangeUnit': 'h',
                'timeLabel': 'last6Hours'
            },
            date.time_diff_value[2]: {
                'timeRange': 12,
                'rangeUnit': 'h',
                'timeLabel': 'last12Hours'
            },
            date.time_diff_value[3]: {
                'timeRange': 24,
                'rangeUnit': 'h',
                'timeLabel': 'last24Hours'
            }
        }
        time_Info = time_unit[str(time_diff)]
        rangeUnit_Info = time_Info['rangeUnit']

        return rangeUnit_Info

    def getTimeLabelId(self):
        FromID = 0 if not date.FromTime_List else date.FromTime_List[0]
        ToID = 0 if not date.ToTime_List else date.ToTime_List[0]
        time_diff = ToID - FromID
        time_unit = {
            date.time_diff_value[0]: {
                'timeRange': 30,
                'rangeUnit': 'm',
                'timeLabel': 'last30Minutes'
            },
            date.time_diff_value[1]: {
                'timeRange': 6,
                'rangeUnit': 'h',
                'timeLabel': 'last6Hours'
            },
            date.time_diff_value[2]: {
                'timeRange': 12,
                'rangeUnit': 'h',
                'timeLabel': 'last12Hours'
            },
            date.time_diff_value[3]: {
                'timeRange': 24,
                'rangeUnit': 'h',
                'timeLabel': 'last24Hours'
            }
        }
        time_Info = time_unit[str(time_diff)]
        timeLabel_Info = time_Info['timeLabel']

        return timeLabel_Info


saved_search_Id_List = []
AlertScenario_Id_List = []
FromTime_List = []
ToTime_List = []
Service_Id_List = []
time_diff_value = ['1800000', '21600000', '43200000', '86400000']
userID = 'f5a08cb056c539d76f373bbc94458e39'